#!/bin/sh
export RESOURCE_LOCATION="/Library/Application Support/Logitech.localized/Logitech Options.localized"
export SIGNED_DRIVER_LOCATION="/Library/Extensions"
export KERNEL_EXTENSION_NAME="LogiMgrDriver.kext"

# On-demand install of signed driver, for 10.13 or higher

echo `date` "installing ${RESOURCE_LOCATION}/${KERNEL_EXTENSION_NAME} to ${SIGNED_DRIVER_LOCATION}/${KERNEL_EXTENSION_NAME}"
ditto -V "${RESOURCE_LOCATION}/${KERNEL_EXTENSION_NAME}" "${SIGNED_DRIVER_LOCATION}/${KERNEL_EXTENSION_NAME}"

if [ -e "${SIGNED_DRIVER_LOCATION}/${KERNEL_EXTENSION_NAME}" ] ; then
    echo `date` "Adjusting owner/permissions of kernel extension..."
    /usr/sbin/chown -R root:wheel "${SIGNED_DRIVER_LOCATION}/${KERNEL_EXTENSION_NAME}"
    /bin/chmod -R ug+r,go-w "${SIGNED_DRIVER_LOCATION}/${KERNEL_EXTENSION_NAME}"
    /usr/bin/touch "${SIGNED_DRIVER_LOCATION}"

    # Load the driver only if the previous driver is not already running
    driverVersion=`kextstat | grep com.logitech.manager.kernel.driver | awk '{print $7}'`

    # If no kernel extension loaded, driverVersion will be empty
    if [ "$driverVersion" == "" ] ; then
        echo `date` "Loading the signed Kext"
        /sbin/kextload "${SIGNED_DRIVER_LOCATION}/${KERNEL_EXTENSION_NAME}"
        exitCode=$?
        if [ $exitCode -ne "0" ] ; then
            echo `date` "Kextload returned error " $exitCode
        fi
    fi

    ## Start time consuming (about 60 sec) kext cache rebuild now instead of on shutdown
    ## when the user is facing a blank screen and might perceive it as a hang and force
    ## reboot.
    echo `date` "Running kextcache -u"
    /usr/sbin/kextcache -u / > /dev/null 2>&1 &
fi

echo `date` "Done"

